@@ -17,7 +17,9 @@ namespace {
   }
 
   static inline std::string &rtrim(std::string &s) {
-    s.erase(std::find_if(s.rbegin(), s.rend(), std::not1(std::ptr_fun<int, int>(std::isspace))).base(), s.end());
+    s.erase(std::find_if(s.rbegin(), s.rend(), 
+                         [](int c) {return !std::isspace(c);}).base(),
+                         s.end());
     return s;
   }
   
